using System.ComponentModel;
using System.Xml.Serialization;

namespace EQIA.EQIDL
{
    public partial class StaticTintedBlendAnimation : StaticScreenPiece
    {
        private string myTexture1, myTexture2;
        private RGB myTint1, myTint2;
        private int myMaxLayerOneTextures, myMaxLayerTwoTextures, myLayerOneTextureIndex, myLayerTwoTextureIndex;

        /// <summary>The bottom layer animation</summary>
        [XmlElement("Texture1", IsNullable = false)]
        [Browsable(true), Description("Bottom animation layer")]
        public string Texture1 { get { return myTexture1; } set { myTexture1 = value; } }

        /// <summary>The top layer animation</summary>
        [XmlElement("Texture2", IsNullable = false)]
        [Browsable(true), Description("Top animation layer")]
        public string Texture2 { get { return myTexture2; } set { myTexture2 = value; } }

        /// <summary>Tint to apply to Texture1</summary>
        [XmlElement("Tint1", IsNullable = false)]
        [Browsable(true), Description("Bottom animation layer tint color")]
        public RGB Tint1 { get { return myTint1; } set { myTint1 = value; } }

        /// <summary>Tint to apply to Texture2</summary>
        [XmlElement("Tint2", IsNullable = false)]
        [Browsable(true), Description("Top animation layer tint color")]
        public RGB Tint2 { get { return myTint2; } set { myTint2 = value; } }

        /// <summary>Maximum number of frames to play from Texture1's animation</summary>
        [XmlElement("MaxLayerOneTextures", IsNullable = false)]
        [Browsable(true), Description("The maximum amount of frames to grab from Texture1's animation")]
        public int MaxLayerOneTextures { get { return myMaxLayerOneTextures; } set { myMaxLayerOneTextures = value; } }

        /// <summary>Maximum number of frames to play from Texture2's animation</summary>
        [XmlElement("MaxLayerTwoTextures", IsNullable = false)]
        [Browsable(true), Description("The maximum amount of frames to grab from Texture2's animation")]
        public int MaxLayerTwoTextures { get { return myMaxLayerTwoTextures; } set { myMaxLayerTwoTextures = value; } }

        /// <summary>Index of the first frame to start with on Texture1's animation</summary>
        [XmlElement("LayerOneTextureIndex", IsNullable = false)]
        [Browsable(true), Description("The first frames to grab from Texture1's animation")]
        public int LayerOneTextureIndex { get { return myLayerOneTextureIndex; } set { myLayerOneTextureIndex = value; } }

        /// <summary>Index of the first frame to start with on Texture2's animation</summary>
        [XmlElement("LayerTwoTextureIndex", IsNullable = false)]
        [Browsable(true), Description("The first frames to grab from Texture2's animation")]
        public int LayerTwoTextureIndex { get { return myLayerTwoTextureIndex; } set { myLayerTwoTextureIndex = value; } }

        public StaticTintedBlendAnimation() : this(null) { }
        public StaticTintedBlendAnimation(EQInterface eqInterface) : base(eqInterface) { }

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            StaticTintedBlendAnimation staticTintedBlendAnimation = obj as StaticTintedBlendAnimation;
            if (staticTintedBlendAnimation != null)
            {
                Texture1 = staticTintedBlendAnimation.Texture1;
                Texture2 = staticTintedBlendAnimation.Texture2;
                Tint1 = staticTintedBlendAnimation.Tint1;
                Tint2 = staticTintedBlendAnimation.Tint2;
                MaxLayerOneTextures = staticTintedBlendAnimation.MaxLayerOneTextures;
                MaxLayerTwoTextures = staticTintedBlendAnimation.MaxLayerTwoTextures;
                LayerOneTextureIndex = staticTintedBlendAnimation.LayerOneTextureIndex;
                LayerTwoTextureIndex = staticTintedBlendAnimation.LayerTwoTextureIndex;
            }
        }
    }
}
